==> couchbasedrupal-8.x-1.0.tar.gz: couchbasedrupal/src/Tests/Cache/BackendGetMultipleTests.php <==
<?php

namespace Drupal\couchbasedrupal\Tests\Cache;

use Drupal\supercache\Tests\Generic\Cache\BackendGetMultipleTests as ScBackendGetMultipleTests;
use Drupal\supercache\Tests\Generic\Cache\BackendClearTests as ScBackendClearTests;

use Drupal\couchbasedrupal\Cache\CouchbaseBackendFactory;
use Drupal\couchbasedrupal\CouchbaseManager;
use Drupal\supercache\Cache\DummyTagChecksum;

use Drupal\Core\Site\Settings;

class BackendGetMultipleTests extends ScBackendGetMultipleTests {
  use BackendGeneralTestCaseTrait;

  /**
   * Test the retrieve with prefixes.
   */
  public function testRetrieveWithPrefix() {
    /** @var \Drupal\couchbasedrupal\Cache\CouchbaseBackend */
    $backend = $this->backend;

    /** @var \Drupal\couchbasedrupal\Cache\CouchbaseBackend */
    $backend2 = $this->backend2;

    $backend->set('en:un:lugar:de:la:mancha', 'value');
    $backend->set('en:un:sitio:de:castilla', 'value');
    $backend->set('en:un:sitio:de:cataluña', 'value');

    $this->assertEquals(2, count($backend->getAll('en:un:sitio')));
    $this->assertEquals(1, count($backend->getAll('en:un:lugar:')));

    $this->assertEquals(2, count($backend->getAllKeys('en:un:sitio')));
    $this->assertEquals(1, count($backend->getAllKeys('en:un:lugar:')));

    // Make sure there is no leakage between binaries.
    $this->assertEquals(0, count($backend2->getAll('en:un:sitio')));
    $this->assertEquals(0, count($backend2->getAll('en:un:lugar:')));

    $this->assertEquals(0, count($backend2->getAllKeys('en:un:sitio')));
    $this->assertEquals(0, count($backend2->getAllKeys('en:un:lugar:')));
  }

}

==> couchbasedrupal-8.x-1.3.tar.gz: couchbasedrupal/src/Tests/Cache/BackendGetMultipleTests.php <==
<?php

namespace Drupal\couchbasedrupal\Tests\Cache;

use Drupal\supercache\Tests\Generic\Cache\BackendGetMultipleTests as GetMultipleTests;

use Drupal\couchbasedrupal\Cache\CouchbaseBackendFactory;
use Drupal\couchbasedrupal\CouchbaseManager;
use Drupal\supercache\Cache\DummyTagChecksum;

use Drupal\Core\Site\Settings;

class BackendGetMultipleTests extends GetMultipleTests {
  use BackendGeneralTestCaseTrait;

  /**
   * Test the retrieve with prefixes.
   */
  public function testRetrieveWithPrefix() {
    /** @var \Drupal\couchbasedrupal\Cache\CouchbaseBackend */
    $backend = $this->backend;

    /** @var \Drupal\couchbasedrupal\Cache\CouchbaseBackend */
    $backend2 = $this->backend2;

    $backend->set('en:un:lugar:de:la:mancha', 'value');
    $backend->set('en:un:sitio:de:castilla', 'value');
    $backend->set('en:un:sitio:de:cataluña', 'value');

    $this->assertEquals(2, count($backend->getAll('en:un:sitio')));
    $this->assertEquals(1, count($backend->getAll('en:un:lugar:')));

    $this->assertEquals(2, count($backend->getAllKeys('en:un:sitio')));
    $this->assertEquals(1, count($backend->getAllKeys('en:un:lugar:')));

    // Make sure there is no leakage between binaries.
    $this->assertEquals(0, count($backend2->getAll('en:un:sitio')));
    $this->assertEquals(0, count($backend2->getAll('en:un:lugar:')));

    $this->assertEquals(0, count($backend2->getAllKeys('en:un:sitio')));
    $this->assertEquals(0, count($backend2->getAllKeys('en:un:lugar:')));
  }

}
